@@ -2,11 +2,8 @@ setpb <-
 function(pb, value)
 {
     if (dopb()) {
-        progress.bar <- getOption("pbapply.pb")
-        control <- switch(progress.bar,
-            txt = getOption("pbapply.txt"),
-            tk = getOption("pbapply.gui"))
-        rval <- switch(progress.bar, 
+        control <- getOption("pboptions")
+        rval <- switch(control$type, 
             txt = setTxtProgressBar(pb, value), 
             tk = tcltk:::setTkProgressBar(pb, value, label=control$label))
     } else rval <- NULL
